@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::WSS;
 use vars '$VERSION';
-$VERSION = '1.05';
+$VERSION = '1.06';
 
 
 use Log::Report 'xml-compile-wss';
@@ -17,7 +17,6 @@ use XML::Compile::Util      qw/SCHEMA2001/;
 use XML::Compile::Schema::BuiltInTypes qw/builtin_type_info/;
 
 use File::Basename          qw/dirname/;
-use Digest::SHA1            qw/sha1_base64/;
 use Encode                  qw/encode/;
 use MIME::Base64            qw/encode_base64/;
 use POSIX                   qw/strftime/;
@@ -109,7 +108,7 @@ sub dateTime($)
 
 sub loadSchemas($$)
 {   my ($thing, $schema, $version) = @_;
-    return if $schema->{"XCW_wss_loaded"}++;
+    return if $schema->{XCW_wss_loaded}++;
 
     $schema->isa('XML::Compile::Cache')
         or error __x"loadSchemas() requires a XML::Compile::Cache object";
